@@ -18,9 +18,9 @@ colors = {
 # Chars definitions
 chars = {
     "OK":        "\u2713",
-    "INFO":      "\u2139",
+    "INFO":      "i",
     "ERROR":     "\u2717",
-    "TITLE":     "\u2BA1",
+    "TITLE":     "*",
     "TEXT":      "",
     "VULN":      "\u2717",
     "NOTVULN":   "\u2713",
